@@ -20,6 +20,10 @@ import chardet
 
 _loggerName = 'beniutils'
 
+countLogWarning = 0
+countLogError = 0
+countLogCritical = 0
+
 
 def initLogger(loggerName=None, loggerLevel=None, logFile=None):
     LOGGER_FORMAT = '%(asctime)s %(levelname)-1s %(message)s', '%Y-%m-%d %H:%M:%S'
@@ -45,17 +49,26 @@ def initLogger(loggerName=None, loggerLevel=None, logFile=None):
 
     class CustomStreamHandler(logging.StreamHandler):
         def emit(self, record):
+
+
+
             try:
                 msg = self.format(record) + self.terminator
                 stream = self.stream
                 # issue 35046: merged two stream.writes into one.
                 func = stream.write
                 if record.levelno == logging.WARNING:
+                    global countLogWarning
+                    countLogWarning+=1
                     func = printcolor.darkYellow
                 elif record.levelno == logging.ERROR:
+                    global countLogError
+                    countLogError += 1
                     func = printcolor.darkRed
                 elif record.levelno == logging.CRITICAL:
-                    func = printcolor.pink
+                    global countLogCritical
+                    countLogCritical += 1
+                    func = printcolor.darkPink
                 func(msg)
                 self.flush()
             except RecursionError:  # See issue 36272
