@@ -27,8 +27,8 @@ FOREGROUND_YELLOW = 0x0E
 FOREGROUND_WHITE = 0x0F
 
 # Windows CMD命令行 背景颜色定义 background colors
-BACKGROUND_BLUE = 0x10
-BACKGROUND_GREEN = 0x20
+BACKGROUND_BLACK = 0x10
+BACKGROUND_DARKGREEN = 0x20
 BACKGROUND_DARKSKYBLUE = 0x30
 BACKGROUND_DARKRED = 0x40
 BACKGROUND_DARKPINK = 0x50
