@@ -4,6 +4,7 @@ import time
 
 import beniutils as b
 import beniutils.print_color as printcolor
+import datetime
 
 workspacePath = None
 
@@ -54,6 +55,7 @@ def runFile(file):
 
 # [[moduleName, parDict], ...]
 def runList(*taskList):
+    startTime = datetime.datetime.now()
     lockFile = checkLockFile()
     try:
         logFolder = b.getPath(workspacePath, "log")
@@ -72,7 +74,23 @@ def runList(*taskList):
         b.error("执行失败")
     finally:
         printcolor.resetColor()
-        b.info("任务结束")
+        b.info("---------------------------------------------------------------------------")
+
+        if b.countLogCritical:
+            printcolor.set_cmd_text_color(printcolor.FOREGROUND_WHITE | printcolor.BACKGROUND_DARKPINK)
+        elif b.countLogError:
+            printcolor.set_cmd_text_color(printcolor.FOREGROUND_WHITE | printcolor.BACKGROUND_DARKRED)
+        elif b.countLogWarning:
+            printcolor.set_cmd_text_color(printcolor.FOREGROUND_BLACK | printcolor.BACKGROUND_DARKYELLOW)
+        else:
+            printcolor.set_cmd_text_color(printcolor.FOREGROUND_BLACK | printcolor.BACKGROUND_DARKGREEN)
+
+        b.info(f"任务结束 warning({b.countLogWarning}) error({b.countLogError}) critical({b.countLogCritical})")
+        passTime = str(datetime.datetime.now() - startTime)
+        if passTime.startswith("0:"):
+            passTime = "0" + passTime
+        b.info(f"用时：{passTime}")
+        printcolor.resetColor()
         b.remove(lockFile)
         if not isDev():
             while True:
